/***********************************************
*                sample1.c
* "Hello World"
* Outputs "Hello World" to a Serial Port
*
* Target: dsPIC30F3011 on Kiwacan KPIC-2840P board
*
* Author: Michael Pearce <mike@kiwacan.co.nz>
*
* Started: 29 August 2006
*
************************************************
*            Version Information
************************************************
* V0.0.1 - 30 August 2006
* Changed to use 8MHz External Crystal as internal 
* RC needs Calibration to get correct Baud rate.
************************************************
* V0.0.0 - 29 August 2006
* Start of project - Get serial output going
***********************************************/
#include <p30f3011.h>


/******************************
* Configuration Bits
******************************/
//_FOSC(CSW_FSCM_OFF & FRC_PLL8); /* Fast RC with PLLx8 = 16MIP Clock Mon/Switch OFF */
 _FOSC(CSW_FSCM_OFF & XT_PLL8);   /* 8MHz Crystal with PLLx8 = 16 MIP */
_FWDT(WDT_OFF);                 /* Watch dog Timer OFF                               */
_FBORPOR(PBOR_OFF & MCLR_EN);   /* Brown Out OFF, MCLR Enabled                       */
_FGS(CODE_PROT_OFF);            /* Code Protect OFF                                  */



char HelloString[]={"Hello World! "};

int main(void)
{
 char *sptr;

 OSCCON=0x3300;                  /* Select Primary Oscillator */

 /* Set up I/O Port */
 ADPCFG=0xFFFF;                  /* Analog ports as Digital I/O */
 TRISB=0x0000;                   /* Port B output Data as well as serial port */
 LATB=0x0000;                    /* Initial Value of 0 */

 /* Set Up UART */
 U1BRG=103;     /* 9600Baud for 16MIP (See FRM Tables) */
                /* Change U1BRG to suit your clock frequency */
 U1MODE=0x8000; /* Enable, 8data, no parity, 1 stop    */
 U1STA =0x8400; /* Enable TX                           */
 

 /* Main Program Loop */
 while(1)
 {
  sptr=HelloString;
  while(*sptr !=0)
  {
   while(U1STAbits.UTXBF==1); /* Wait until TX buf read for new data */
   U1TXREG=*sptr;
   LATB=*sptr;
   sptr++;
  }
 }
 return(0);
}



